﻿using UnityEngine;
using System.Collections;

public class PlayerHealth : MonoBehaviour 
{
	//This script controls the player's health.

	public float health = 100f; //Player's Health.
	public float repeatDamagePeriod = 2f; //How often the player can be damaged;
	public float hurtForce = 10f; //Amount of force pushed on the player when damage taken by an enemy.
	public float damageAmount = 10f; //Amount of damage taken.
	private float lastTimeHit; //The last time the player was hit.

	private Sprite healthSprite; //Reference to the Sprite array used to display hte Player's health.
	private _2dCharacterController characterControl;

	public AudioClip damageClip; //Audio clip to play when player take's damage.
	private Animator anim; //Reference to the Player's animations.

	// Use this for initialization
	void Awake () 
	{
		//Setting up the references.
		characterControl = GetComponent<_2dCharacterController>();
		//healthSprite = GameObject.Find("hud_heart").GetComponent(SpriteRenderer);
		anim = GetComponent<Animator>();
	}

	void OnCollisionEnter2D (Collision2D col)
	{
		//If the colliding gameObject is an enemy...
		if(col.gameObject.tag == "Enemy")
		{
			//...and if the time exceeds the time of the last hit plus the time between hits...
			if(Time.time > lastTimeHit + repeatDamagePeriod)
			{
				//...and if the player still has health...
				if(health > 0f)
				{
					//...take damage and reset the lastTimeHit.
					TakeDamage(col.transform);
					lastTimeHit = Time.time;
				}

					//If the player does not have health, do some stuff.
				else
				{
					// ... disable user Player Control script
					GetComponent<_2dCharacterController>().enabled = false;
					
					// ... disable the Gun script to stop a dead guy shooting a nonexistant bazooka
					//GetComponentInChildren<Gun>().enabled = false;
					
					// ... Trigger the 'Die' animation state
					anim.SetTrigger("Die");
				}
			}
		}
	}
	
	
	void TakeDamage (Transform enemy)
	{
		// Make sure the player can't jump.
		characterControl.jump = false;
		
		// Create a vector that's from the enemy to the player with an upwards boost.
		Vector3 hurtVector = transform.position - enemy.position + Vector3.up * 5f;
		
		// Add a force to the player in the direction of the vector and multiply by the hurtForce.
		rigidbody2D.AddForce(hurtVector * hurtForce);
		
		// Reduce the player's health by 10.
		health -= damageAmount;
		
		// Update what the health bar looks like.
		//UpdateHealthSprite();
		
		// Play audio clip of the player getting hurt.
		AudioSource.PlayClipAtPoint(damageClip, transform.position);
	}
	
	
	//public void UpdateHealthSprite ()
	//{
		// Set the health sprite relevent to the players overall health.

	//}
}
