﻿using UnityEngine;
using System.Collections;

public class _2dCharacterController : MonoBehaviour {

		[HideInInspector]
		public bool facingRight = true;			// For determining which way the player is currently facing.
		[HideInInspector]
		public bool jump = false;				// Condition for whether the player should jump.
		
		
		public float moveForce = 365f;			// Amount of force added to move the player left and right.
		public float maxSpeed = 5f;				// The fastest the player can travel in the x axis.
		public AudioClip walkClip;				// Clip for when the player steps.
		public AudioClip jumpClip;				// Clip for when the player jumps.
		public float jumpForce = 1000f;			// Amount of force added when the player jumps.
		//public AudioClip[] taunts;				// Array of clips for when the player taunts.
		//public float tauntProbability = 50f;	// Chance of a taunt happening.
		//public float tauntDelay = 1f;			// Delay for when the taunt should happen.
		
		
		//private int tauntIndex;					// The index of the taunts array indicating the most recent taunt.
		public Transform groundCheck;			// A position marking where to check if the player is grounded.
		private bool grounded = false;			// Whether or not the player is grounded.
		private float groundRadius = 0.2f;
		public LayerMask whatIsGround;
		private Animator anim;				// Reference to the player's animator component.
		
		
		void Awake()
		{
			// Setting up references.
			groundCheck = transform.Find("groundCheck");
			anim = GetComponent<Animator>();
		}
		
		
		void Update()
		{
			//If the player steps, play a sound
			if(Input.GetButton("Horizontal") && grounded)
			{
				if(audio.isPlaying == false)
				{
				audio.clip = walkClip;
				audio.loop = true;
				audio.Play();
				}
			}

			else
			{
				if(audio.isPlaying == true)
				{
				audio.Stop();
				audio.loop = false;
				}
			}

			// If the jump button is pressed and the player is grounded then the player should jump.
			if(Input.GetButtonDown("Jump") && grounded)
				jump = true;

		}
		
		
		void FixedUpdate ()
		{
			grounded = Physics2D.OverlapCircle(groundCheck.position, groundRadius, whatIsGround);  
			anim.SetBool("Ground", grounded);
			
			// Cache the horizontal input.
			float h = Input.GetAxis("Horizontal");
			
			// The Speed animator parameter is set to the absolute value of the horizontal input.
			anim.SetFloat("Speed", Mathf.Abs(h));
			
			// If the player is changing direction (h has a different sign to velocity.x) or hasn't reached maxSpeed yet...
			if(h * rigidbody2D.velocity.x < maxSpeed)
				// ... add a force to the player.
				rigidbody2D.AddForce(Vector2.right * h * moveForce);
			
			// If the player's horizontal velocity is greater than the maxSpeed...
			if(Mathf.Abs(rigidbody2D.velocity.x) > maxSpeed)
				// ... set the player's velocity to the maxSpeed in the x axis.
				rigidbody2D.velocity = new Vector2(Mathf.Sign(rigidbody2D.velocity.x) * maxSpeed, rigidbody2D.velocity.y);
			
			// If the input is moving the player right and the player is facing left...
			if(h > 0 && !facingRight)
				// ... flip the player.
				Flip();
			// Otherwise if the input is moving the player left and the player is facing right...
			else if(h < 0 && facingRight)
				// ... flip the player.
				Flip();
			
			// If the player should jump...
			if(jump)
			{
				// Set the Jump animator trigger parameter.
				anim.SetTrigger("Jump");
				
				// Play jump audio clip.
				AudioSource.PlayClipAtPoint(jumpClip, transform.position);

				// Add a vertical force to the player.
				rigidbody2D.AddForce(new Vector2(0f, jumpForce));
				
				// Make sure the player can't jump again until the jump conditions from Update are satisfied.
				jump = false;
			}
		}


		void Flip ()
		{
			// Switch the way the player is labelled as facing.
			facingRight = !facingRight;
		
			// Multiply the player's x local scale by -1.
			Vector3 theScale = transform.localScale;
			theScale.x *= -1;
			transform.localScale = theScale;
		}
}